#
# spec file for package tailscale
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tailscale
Version:        1.62.1
Release:        1.1
Summary:        The easiest, most secure way to use WireGuard and 2FA
License:        BSD-3-Clause
Group:          Productivity/Networking/Security
URL:            https://github.com/tailscale/tailscale
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        tailscaled.service
Source3:        tailscaled.defaults
Patch1:         build-verbose.patch
Patch2:         disable-auto-update.patch
BuildRequires:  git
BuildRequires:  golang-packaging
BuildRequires:  golang(API) = 1.22
ExcludeArch:    i586
%{?systemd_requires}

%description
Tailscale is a modern VPN built on top of Wireguard. It works like an overlay
network between the computers of your networks using NAT traversal.

%prep
%autosetup -a1 -p1

%build
%ifnarch ppc64
export GOFLAGS="-buildmode=pie"
%endif
export CGO_ENABLED=0

./build_dist.sh ./cmd/tailscale
./build_dist.sh ./cmd/tailscaled

%install
mkdir -p %{buildroot}%{_sharedstatedir}/%{name}

install -D -p -m 0755 %{name} %{buildroot}%{_bindir}/%{name}
install -D -p -m 0755 %{name}d %{buildroot}%{_sbindir}/%{name}d

# service
install -D -p -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}d.service
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}d

# defaults
install -D -p -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/default/%{name}d

%pre
%service_add_pre %{name}d.service

%post
%service_add_post %{name}d.service

%preun
%service_del_preun %{name}d.service

%postun
%service_del_postun %{name}d.service

%files
%license LICENSE PATENTS
%doc README.md SECURITY.md
%config(noreplace) %{_sysconfdir}/default/%{name}d
%dir %{_sharedstatedir}/%{name}
%{_bindir}/%{name}
%{_sbindir}/%{name}d
%{_unitdir}/%{name}d.service
%{_sbindir}/rc%{name}d

%changelog
* Sat Mar 30 2024 Richard Rahl <rrahl0@proton.me>
- update to 1.62.1:
  * Send load balancing hint HTTP request header
  * Fixed: Kubernetes operator proxies should not accept subnet routes
* Thu Mar 14 2024 rrahl0@proton.me
- update to 1.62.0:
  * IPv6 support detection in a container environment is improved
  * New: Web interface now uses ACL grants to manage access on tagged devices
  * Tailscale SSH connections now disable unnecessary hostname canonicalization
  * tailscale bugreport command for generating diagnostic logs now contain ethtool information
  * Mullvad's family-friendly server is added to the list of well known DNS over HTTPS (DoH) servers
  * DNS over HTTP requests now contain a timeout
  * TCP forwarding attempts in userspace mode now have a per-client limit
  * Endpoints with link-local IPv6 addresses is preferred over private addresses
  * WireGuard logs are less verbose
  * Go min. version 1.22.1
  * DERP server region no longer changes if connectivity to the new DERP region is degraded
- update to 1.60.1:
  * Exposing port 8080 to other devices on your tailnet works as expected
* Tue Feb 20 2024 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Add disable-auto-update.patch to prevent auto updates and instead
  ask users to use Zypper to update manually
* Tue Feb 20 2024 Richard Rahl <rrahl0@proton.me>
- change to the non deprecated manualrun
* Fri Feb 16 2024 alexandre.vicenzi@suse.com
- Spec cleanup
  * Use tar_scm to avoid commit hashes in the spec
  * Use tailscale build scripts
  * Drop ProtectClock fix for Leap, DeviceAllow fixes it
- Add build-verbose.patch to get go flags into build log
- Enable PrivateDevices but allow access to /dev/net/tun in tailscaled.service
* Fri Feb 16 2024 Richard Rahl <rrahl0@proton.me>
- update to 1.60.0:
  * minimum go version 1.22
  * authentication: present users with a valid login page when
    attempting to login even after leaving device unattended for several days
  * networking: mute noisy peer mtu discovery errors
  * networking: expose gVisor metrics in debug mode
  * port mapper: support legacy "urn:dslforum-org" port mapping services
  * port mapper: fix crash when no support mapping services found
  * ssh: log warning when unable to find SSH host keys
  * serve: improve error message when running as non-root
  * Detect when Tailscale is running on Digital Ocean and automatically
    use Digital Ocean's DNS resolvers
  * enable app connectors to install routes for domains that resolve to CNAME
    records
  * support pre-configured routes from control server
  * add new read-only mode
  * tailscale status command: fix output formatting Tailnet
    includes location-based exit nodes
  * a new ProxyClass custom resource that allows to provide custom
    configuration for cluster resources that the operator creates
  * ACL tags for the operator can now be configured via Helm chart values
  * routing to Ingress backends that require an exact path without a slash
* Wed Feb  7 2024 Richard Rahl <rrahl0@proton.me>
- make rpm not overwrite /etc/default/taiscaled
- defattr everything to root
* Sat Feb  3 2024 Richard Rahl <rrahl0@proton.me>
- no stripping of binaries
- add commitID to binaries for upstream
- add directory for saved configs
* Tue Jan 23 2024 Richard Rahl <rrahl0@proton.me>
- switch services to manual
- update to version 1.58.2:
  * Fixed: [App connectors][app-connectors] have improved scheduling
    and merging of route changes under some conditions
  * Fixed: Crash when performing UPnP portmapping on older routers
    with no supported portmapping services
* Fri Jan 19 2024 Richard Rahl <rrahl0@proton.me>
- update to version 1.58.0:
  * portmap: check the epoch from NAT-PMP & PCP, establish new portmapping if it changes
  * portmap: better handle multiple interfaces
  * portmap: handle multiple UPnP discovery responses
  * increase the number of 4via6 site IDs from 256 to 65,536
  * taildrop: allow category Z unicode characters
  * increased binary size with 1.56 is resolved in 1.58
  * Reduce home DERP flapping when there's still an active connection
  * device web ui: fixed issue when accessing shared devices
  * device web ui: fixed login issue when accessed over https
* Wed Jan 10 2024 Richard Rahl <rrahl0@proton.me>
- fix an issue with Leap, where ProtectClock prevents to connect to
  /dev/net/tun
* Fri Dec 15 2023 Richard Rahl <rrahl0@proton.me>
- update to version 1.56.1:
  * Fixed: Web interface redirects to the correct self IP known by source peer
  * Fixed: Usage of slices.Compact from app connector domains list
* Fri Dec 15 2023 Richard Rahl <rrahl0@proton.me>
- fix version output to what upstream expects
* Wed Dec 13 2023 rrahl0@proton.me
- Update to version 1.56.0:
  * improve responsiveness under load, especially with bidirectional traffic
  * improve UPnP portmapping
  * add tailscale whois subcommand to observe metadata associated with a Tailscale IP
  * include tailnet name and profile ID in tailscale switch --list to disambiguate
    profiles with common login names
  * improve tailscale web interface for configuring some device settings such as exit nodes,
    subnet routers, and Tailscale SSH
  * improve containerboot to symlink its socket file if possible,
    making the tailscale CLI work without --socket=/tmp/tailscale.sock
  * add support in Kubernetes operator cluster egress for referring to a tailnet service
    by its MagicDNS name
- Update to version 1.54.1:
  * no relevant updates to the linux version
* Fri Nov 24 2023 Richard Rahl <rrahl0@proton.me>
- tailscale couldn't connect to /dev/net/tun
* Thu Nov 23 2023 rrahl0@proton.me
- Update to version 1.54.0:
  * improve throughput substantially for UDP packets over TUN device with recent Linux kernels
- Update to version 1.52.1:
  * no linux improvements
- Update to version 1.52.0:
  * tailscale set command flag --auto-update is added to opt in to automatic client updates
  * tailscale serve and tailscale funnel commands are updated for improved usability
  * tailscale update command for manual updates is now in beta
  * Taildrop file transfer displays a progress meter
  * nftables auto-detection is improved when TS_DEBUG_FIREWALL_MODE=auto is used
  * DNS detection of NetworkManager with configured but absent systemd-resolved
  * Taildrop now resumes file transfers after partial transfers are interrupted
  * tailscale up command displays a message about client updates when newer versions are available
  * tailscale status command displays a message about client updates when newer versions are available
  * tailscale cert command renews in the background. The current certificate only displays if it has expired.
* Mon Oct  2 2023 rrahl0@proton.me
- Update to version 1.50.1:
  * fix bug where serve config could get wiped
  * Funnel support for tsnet apps
  * fix potential crash with UPnP
* Sat Sep 30 2023 rrahl0@proton.me
- Update to version 1.50.0:
  * Update tailscale{,d} licenses
  * Update Quad9 addresses and references
  * Adds support for Wikimedia DNS using DNS-over-HTTPS
- Update to version 1.48.1:
  * no relevant updates
- Update to version 1.48.2:
  * Improvements to Mullvad exit nodes
* Fri Aug 18 2023 Richard Rahl <rrahl0@proton.me>
- Initial revision
